/**
 * Tic Tac Toe Class
 * @author Ananda Guna
 * This is a board class that simulates a TicTacToe game. 
 * The board object will be accessed by players 
  */

import java.io.*;
public class TicTacToe {
	public static final int EMPTY=0, X=1, O=-1; // X is 1 and O is -1
	public static final int N = 3;     // size of the board
	private int board[][]=new int[N][N];   // actual board
	protected int player;                 // player number (1 or -1)
	public boolean played = false;
	public boolean gameOver = false;
	// constructors
	public TicTacToe() {}
	
	/**
	 * This method clears the board.
	 */
	public void clearBoard(){
		for (int i = 0; i < board.length; i++)
			for (int j = 0; j < board[0].length; j++)
				board[i][j] = EMPTY;
		player = 1;
	}
	
	/** This method marks the cell with current player
	 * given the input arguments i and j
	 * @param i the row index
	 * @param j the column index
	 */
	public void markCell(int i, int j){
        if (i < 0 || i > board.length) {
        	System.out.println("Invalid Move");
        	return;
        }
        if (j < 0 || j > board[0].length) {
        	System.out.println("Invalid Move");
        	return;
        }
		
        if (board[i][j] == EMPTY) {
        	if (player == X) {
        		board[i][j] = X;
        		player = O;
        	}
        	else {
        		board[i][j] = O;
        		player = X;
        	}
        }
        else
        	System.out.println("Invalid Move");
	}

	/**
	 * This method checks if the current board is a win for the mark
	 * @param mark is the current player code X or O
	 * @return true if the board is a win for the current player or
	 * false otherwise
	 */
	public boolean isWin(int mark){
		if (mark == X) {
			for (int i = 0; i < board.length; i++)
				if (board[i][0] == X && board[i][1] == X && board[i][2] == X)
					return true;
			for (int i = 0; i < board[0].length; i++)
				if (board[0][i] == X && board[1][i] == X && board[2][i] == X)
					return true;
			if (board[0][0] == X && board[1][1] == X && board[2][2] == X)
				return true;
			if (board[0][2] == X && board[1][1] == X && board[2][0] == X)
				return true;
		}	
		else {
			for (int i = 0; i < board.length; i++)
				if (board[i][0] == O && board[i][1] == O && board[i][2] == O)
					return true;
			for (int i = 0; i < board[0].length; i++)
				if (board[0][i] == O && board[1][i] == O && board[2][i] == O)
					return true;
			if (board[0][0] == O && board[1][1] == O && board[2][2] == O)
				return true;
			if (board[0][2] == O && board[1][1] == O && board[2][0] == O)
				return true;
		}
		return false;
	}

	/**
	 * This method returns true if the board is full.
	 */
	public boolean boardFull()
	{
		for (int i = 0; i < board.length; i++)
			for (int j = 0; j < board[0].length; j++)
				if (board[i][j] == EMPTY)
					return false;
		
		gameOver = true;
		return true;
	}

	/**
	 * Thie method returns true if the game is a draw
	 */
	public boolean isDraw()
	{
		if (!boardFull())
			return false;
		if (isWin(X))
			return false;
		if (isWin(O))
			return false;
		
		gameOver = true;
		return true;
	}

    /**
	 * An accessor method to get the board content. Will be used by
	 * Player classes to see the state of the board
	 * @param i the row index
	 * @param j the column index
	 * @return the value of the position (0, 1 or -1)
	 */
	public int getBoard(int i,int j)
	{
		return board[i][j];
	}
	/** ToString method.
	 * Returns the board printed as a tic tac toe board
	 * This method is complete. You can modify to make output look good.
	 */
	public String toString(){
		String s = "";
		for (int i=0;i<N;i++){
			for (int j=0;j<N;j++){
				switch (board[i][j])
				{
				case X: s += "X";break;
				case O: s += "O"; break;
				case 0: s += " "; break;
				}
		    if (j<N) s += "|";
			}
		  if (i<N) { s += "\n ";
		             for (int j=0;j<2*N-2;j++)
		            	 s += "-";
		             s += "\n";
		  }
		  }
		return s;
	}
	
	
  
}
